Gemini Functions
================

----

.. note::

  Even though the functions are written as ``robin_stocks.module.function``, the module
  name is unimportant when calling a function. Simply use ``robin_stocks.function`` for all functions.

Sending Requests to API
-----------------------

----

.. automodule:: robin_stocks.gemini.helper
   :members: request_get,request_post

Logging In and Authentication
-----------------------------

----

.. automodule:: robin_stocks.gemini.authentication
   :members: login,heartbeat

Getting Crypto Information
--------------------------

----

.. automodule:: robin_stocks.gemini.crypto
   :members:

Placing and Cancelling Orders
-----------------------------

----

.. automodule:: robin_stocks.gemini.orders
   :members:


Getting Account Information
---------------------------

----

.. automodule:: robin_stocks.gemini.account
   :members: